@@ -1,6 +1,6 @@
 from .main import run, Effect, Strand, TapystryError
 
-from .main import Broadcast, Receive, CallFork, First, Call, Cancel, Sleep, Intercept
+from .main import Broadcast, Receive, CallFork, First, Call, Cancel, Sleep, Intercept, DebugTree
 from .utils import as_effect, runnable
 from .effects import Sequence, Fork, Join, Race, Subscribe
 from .concurrency import Lock, Queue
